pub enum AcceptorCommand {
Stop(Sender<()>),
Terminate,
Pause,
Resume,
Timer,
}Expand description
Command sent to the accept loop.
Variants
Stop(Sender<()>)
Stops accepting and closes the listeners, then signals the sender.
Terminate
Stops accepting and closes the listeners immediately.
Pause
Stops accepting connections.
Resume
Resumes accepting connections.
Timer
Re-registers listeners that were paused after an accept error.