ServiceRuntime

Struct ServiceRuntime 

pub struct ServiceRuntime<St>(/* private fields */);

Implementations

Source

impl<St: State<St, Io> + Clone + 'static> ServiceRuntime<St>

pub fn service<S>(&self, name: &str, svc: impl IntoService<S, St, Io>) -> &Self
where S: Service<St, Io> + 'static,

Register service.

Name of the service must be registered during configuration stage with ServiceConfig::bind() or ServiceConfig::listen() methods.

Panics

Panics if service with specified name is registered already