WorkerStop

Struct WorkerStop 

pub struct WorkerStop(/* private fields */);
Future returned when stopping a worker.

Resolves to true if the worker’s service shut down within the timeout, or if the worker was already gone. Resolves to false if the timeout expired, or if the worker was stopped before its service was created.