ServerBuilder

Struct ServerBuilder 

pub struct ServerBuilder<St = ()> { /* private fields */ }
Streaming service builder

This type can be used to construct an instance of net streaming server through a builder-like pattern.

Implementations

Source

impl<St> ServerBuilder<St>
where St: State<St, Io> + Clone + 'static,

pub fn new<F>(state: F) -> ServerBuilder<St>
where F: AsyncFn() -> Result<St, &'static str> + Send + Clone + 'static,

Create new Server builder instance.

Provided function get called during worker runtime configuration stage and must construct server state.

pub fn with_default() -> ServerBuilder<St>
where St: Default,

Create new Server builder instance with default state factory.

pub fn name<T: AsRef<str>>(self, name: T) -> Self

Set server name.

Name is used for worker thread name

pub fn workers(self, num: usize) -> Self

Set number of workers to start.

By default server uses number of available logical cpu as workers count.

pub fn backlog(self, num: i32) -> Self

Set the maximum number of pending connections.

This refers to the number of clients that can be waiting to be served. Exceeding this number results in the client getting an error when attempting to connect. It should only affect servers under significant load.

Generally set in the 64-2048 range. Default value is 2048.

This method should be called before bind() method call.

pub fn maxconn(self, num: usize) -> Self

Sets the maximum per-worker number of concurrent connections.

All socket listeners will stop accepting connections when this limit is reached for each worker.

By default max connections is set to a 25k per worker.

pub fn stop_runtime(self) -> Self

Stop ntex runtime when server get dropped.

By default “stop runtime” is disabled.

pub fn stop_on_panic(self) -> Self

Stops the server when one of the workers panics.

By default, “stop on panic” is disabled.

pub fn disable_signals(self) -> Self

Disable signal handling.

By default, signal handling is enabled.

pub fn enable_affinity(self) -> Self

Enable cpu affinity.

By default, affinity is disabled.

pub fn graceful_shutdown(self) -> Self

Graceful shutdown.

Gracefully shuts down on SIGTERM, SIGSEGV, or SIGQUIT. By default, graceful shutdown is disabled.

pub fn shutdown_timeout<T: Into<Millis>>(self, timeout: T) -> Self

Timeout for graceful worker shutdown.

After receiving a stop signal, workers have this much time to finish serving requests. Workers that are still alive after the timeout are forcefully dropped.

By default, the shutdown timeout is set to 30 seconds.

pub fn status_handler<F>(self, handler: F) -> Self
where F: FnMut(ServerStatus) + Send + 'static,

Sets the server status handler.

The server calls this handler on every internal status update.

pub async fn configure<F>(self, f: F) -> Result<Self>
where F: AsyncFn(ServiceConfig<St>) -> Result<()>,

Execute external async configuration as part of the server building process.

This function is useful for moving parts of configuration to a different module or even library.

pub fn bind<F, S, I>( self, name: impl AsRef<str>, addr: impl ToSocketAddrs, cfg: impl Into<SharedCfg>, factory: F, ) -> Result<Self>
where F: AsyncFn(&St) -> I + Send + Clone + 'static, S: Service<St, Io> + 'static, I: IntoService<S, St, Io> + 'static, St: State<St, Io> + 'static,

Add new service to the server.

pub fn bind_uds<F, I, S>( self, name: impl AsRef<str>, addr: impl AsRef<Path>, cfg: impl Into<SharedCfg>, factory: F, ) -> Result<Self>
where F: AsyncFn(&St) -> I + Send + Clone + 'static, I: IntoService<S, St, Io> + 'static, S: Service<St, Io> + 'static, St: State<St, Io> + 'static,

Add new unix domain service to the server.

pub fn listen_uds<F, I, S>( self, name: impl AsRef<str>, lst: UnixListener, cfg: impl Into<SharedCfg>, factory: F, ) -> Result<Self>
where F: AsyncFn(&St) -> I + Send + Clone + 'static, I: IntoService<S, St, Io> + 'static, S: Service<St, Io> + 'static, St: State<St, Io> + 'static,

Add new unix domain service to the server. Useful when running as a systemd service and a socket FD can be acquired using the systemd crate.

pub fn listen<F, S, I>( self, name: impl AsRef<str>, lst: TcpListener, cfg: impl Into<SharedCfg>, factory: F, ) -> Result<Self>
where F: AsyncFn(&St) -> I + Send + Clone + 'static, S: Service<St, Io> + 'static, I: IntoService<S, St, Io> + 'static, St: State<St, Io> + 'static,

Add new service to the server.

pub fn run(self) -> Server<Connection>

Starts processing incoming connections and return server controller.