pub struct ServerBuilder<St = ()> { /* private fields */ }Expand description
Streaming service builder
This type can be used to construct an instance of net streaming server through a
builder-like pattern.
Implementations
Sourceimpl<St> ServerBuilder<St>
impl<St> ServerBuilder<St>
Sourcepub fn new<F>(state: F) -> ServerBuilder<St>
pub fn new<F>(state: F) -> ServerBuilder<St>
Create new Server builder instance.
Provided function get called during worker runtime configuration stage and must construct server state.
Sourcepub fn with_default() -> ServerBuilder<St>where
St: Default,
pub fn with_default() -> ServerBuilder<St>where
St: Default,
Create new Server builder instance with default state factory.
Sourcepub fn name<T: AsRef<str>>(self, name: T) -> Self
pub fn name<T: AsRef<str>>(self, name: T) -> Self
Set server name.
Name is used for worker thread name
Sourcepub fn workers(self, num: usize) -> Self
pub fn workers(self, num: usize) -> Self
Set number of workers to start.
By default server uses number of available logical cpu as workers count.
Sourcepub fn backlog(self, num: i32) -> Self
pub fn backlog(self, num: i32) -> Self
Set the maximum number of pending connections.
This refers to the number of clients that can be waiting to be served. Exceeding this number results in the client getting an error when attempting to connect. It should only affect servers under significant load.
Generally set in the 64-2048 range. Default value is 2048.
This method should be called before bind() method call.
Sourcepub fn maxconn(self, num: usize) -> Self
pub fn maxconn(self, num: usize) -> Self
Sets the maximum per-worker number of concurrent connections.
All socket listeners will stop accepting connections when this limit is reached for each worker.
By default max connections is set to a 25k per worker.
Sourcepub fn stop_runtime(self) -> Self
pub fn stop_runtime(self) -> Self
Stop ntex runtime when server get dropped.
By default “stop runtime” is disabled.
Sourcepub fn stop_on_panic(self) -> Self
pub fn stop_on_panic(self) -> Self
Stops the server when one of the workers panics.
By default, “stop on panic” is disabled.
Sourcepub fn disable_signals(self) -> Self
pub fn disable_signals(self) -> Self
Disable signal handling.
By default, signal handling is enabled.
Sourcepub fn enable_affinity(self) -> Self
pub fn enable_affinity(self) -> Self
Enable cpu affinity.
By default, affinity is disabled.
Sourcepub fn graceful_shutdown(self) -> Self
pub fn graceful_shutdown(self) -> Self
Graceful shutdown.
Gracefully shuts down on SIGTERM, SIGSEGV, or SIGQUIT. By default, graceful shutdown is disabled.
Sourcepub fn shutdown_timeout<T: Into<Millis>>(self, timeout: T) -> Self
pub fn shutdown_timeout<T: Into<Millis>>(self, timeout: T) -> Self
Timeout for graceful worker shutdown.
After receiving a stop signal, workers have this much time to finish serving requests. Workers that are still alive after the timeout are forcefully dropped.
By default, the shutdown timeout is set to 30 seconds.
Sourcepub fn status_handler<F>(self, handler: F) -> Self
pub fn status_handler<F>(self, handler: F) -> Self
Sets the server status handler.
The server calls this handler on every internal status update.
Sourcepub async fn configure<F>(self, f: F) -> Result<Self>
pub async fn configure<F>(self, f: F) -> Result<Self>
Execute external async configuration as part of the server building process.
This function is useful for moving parts of configuration to a different module or even library.
Sourcepub fn bind<F, S, I>(
self,
name: impl AsRef<str>,
addr: impl ToSocketAddrs,
cfg: impl Into<SharedCfg>,
factory: F,
) -> Result<Self>
pub fn bind<F, S, I>( self, name: impl AsRef<str>, addr: impl ToSocketAddrs, cfg: impl Into<SharedCfg>, factory: F, ) -> Result<Self>
Add new service to the server.
Sourcepub fn bind_uds<F, I, S>(
self,
name: impl AsRef<str>,
addr: impl AsRef<Path>,
cfg: impl Into<SharedCfg>,
factory: F,
) -> Result<Self>
pub fn bind_uds<F, I, S>( self, name: impl AsRef<str>, addr: impl AsRef<Path>, cfg: impl Into<SharedCfg>, factory: F, ) -> Result<Self>
Add new unix domain service to the server.
Sourcepub fn listen_uds<F, I, S>(
self,
name: impl AsRef<str>,
lst: UnixListener,
cfg: impl Into<SharedCfg>,
factory: F,
) -> Result<Self>
pub fn listen_uds<F, I, S>( self, name: impl AsRef<str>, lst: UnixListener, cfg: impl Into<SharedCfg>, factory: F, ) -> Result<Self>
Add new unix domain service to the server. Useful when running as a systemd service and a socket FD can be acquired using the systemd crate.
Sourcepub fn listen<F, S, I>(
self,
name: impl AsRef<str>,
lst: TcpListener,
cfg: impl Into<SharedCfg>,
factory: F,
) -> Result<Self>
pub fn listen<F, S, I>( self, name: impl AsRef<str>, lst: TcpListener, cfg: impl Into<SharedCfg>, factory: F, ) -> Result<Self>
Add new service to the server.
Sourcepub fn run(self) -> Server<Connection> ⓘ
pub fn run(self) -> Server<Connection> ⓘ
Starts processing incoming connections and return server controller.