ServiceRuntime

Struct ServiceRuntime 

pub struct ServiceRuntime<Cfg>(/* private fields */);

Implementations

Source

impl<Cfg: Clone + 'static> ServiceRuntime<Cfg>

pub fn cfg(&self) -> &Cfg

Server configuration

pub fn service<S>( &self, name: &str, cfg: impl Into<SharedCfg>, svc: impl IntoService<S, Cfg, Io>, ) -> &Self
where S: Service<Cfg, Io> + 'static,

Register service.

Name of the service must be registered during configuration stage with ServiceConfig::bind() or ServiceConfig::listen() methods.

Panics

Panics if service with specified name is registered already

pub fn map_cfg<T>(&self, st: T) -> ServiceRuntime<T>
where T: Clone + 'static,

Map server configuration.