pub struct ServiceRuntime<Cfg>(/* private fields */);Implementations
Sourceimpl<Cfg: Clone + 'static> ServiceRuntime<Cfg>
impl<Cfg: Clone + 'static> ServiceRuntime<Cfg>
Sourcepub fn service<S>(&self, name: &str, svc: impl IntoService<S, Cfg, Io>) -> &Self
pub fn service<S>(&self, name: &str, svc: impl IntoService<S, Cfg, Io>) -> &Self
Register service.
Name of the service must be registered during configuration stage with
ServiceConfig::bind() or ServiceConfig::listen() methods.
Panics
Panics if service with specified name is registered already
Sourcepub fn map_cfg<T>(&self, st: T) -> ServiceRuntime<T>where
T: Clone + 'static,
pub fn map_cfg<T>(&self, st: T) -> ServiceRuntime<T>where
T: Clone + 'static,
Map server configuration.