pub struct Server<T> { /* private fields */ }Expand description
Controller and completion future for a running server.
Clones can pause, resume, stop, or submit items to the server. Awaiting a
Server resolves when the server has stopped.
Implementations
Sourceimpl<T> Server<T>
impl<T> Server<T>
Sourcepub fn builder() -> ServerBuilder
pub fn builder() -> ServerBuilder
Creates a network server builder with no application configuration.
Sourcepub fn process(&self, item: T) -> Result<(), T>
pub fn process(&self, item: T) -> Result<(), T>
Submits an item to the worker pool.
Returns the item unchanged if the server is paused or cannot accept it.